## NOTE: Lots of files in various subdirectories have the same name (such as
## "LICENSE") so this short macro allows us to distinguish them by using their
## directory names (from the source tree) as prefixes for the files.
%global         add_to_doc_files()      \
        mkdir -p %{buildroot}%{_docdir}/%{name}-%{version} ||: ; \
        cp -p %1  %{buildroot}%{_docdir}/%{name}-%{version}/$(echo '%1' | sed -e 's!/!.!g')

Name:           webkitgtk3
Version:        1.3.3
Release:        1%{?dist}
Summary:        GTK+ Web content engine library

Group:          Development/Libraries
License:        LGPLv2+ and BSD
URL:            http://www.webkitgtk.org/

Source0:        http://www.webkitgtk.org/webkit-%{version}.tar.gz

Patch0:         webkit-1.1.14-nspluginwrapper.patch

BuildRequires:  bison
BuildRequires:  chrpath
BuildRequires:  enchant-devel
BuildRequires:  flex
BuildRequires:  geoclue-devel
BuildRequires:  gettext
BuildRequires:  gperf
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  gtk3-devel
BuildRequires:  libsoup-devel >= 2.27.91
BuildRequires:  libicu-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libxslt-devel
BuildRequires:  libXt-devel
BuildRequires:  pcre-devel
BuildRequires:  sqlite-devel
BuildRequires:  gobject-introspection-devel

## Conditional dependencies...
%if %{with pango}
BuildRequires:  pango-devel
%else
BuildRequires:  cairo-devel
BuildRequires:  fontconfig-devel
BuildRequires:  freetype-devel
%endif

%description
WebKitGTK+ is the port of the portable web rendering engine WebKit to the
GTK+ platform.

This package contains WebKitGTK+ for GTK+ 3.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       gtk3-devel

%description    devel
The %{name}-devel package contains libraries, build data, and header
files for developing applications that use %{name}.

%prep
%setup -qn "webkit-%{version}"
%patch0 -p1 -b .nspluginwrapper

%build
CFLAGS="%{optflags} -DLIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY" %configure                                                   \
                        --with-gtk=3.0                          \
                        --disable-jit                           \
                        --enable-geolocation                    \
                        --enable-introspection

mkdir -p DerivedSources/webkit
mkdir -p DerivedSources/WebCore

# no %%{_smp_mflags} because of http://bugs.webkit.org/show_bug.cgi?id=34846
make

%install
make install DESTDIR=%{buildroot}

chrpath --delete Programs/GtkLauncher
install -d -m 755 %{buildroot}%{_libexecdir}/%{name}
install -m 755 Programs/GtkLauncher %{buildroot}%{_libexecdir}/%{name}

%find_lang webkit-3.0

## Finally, copy over and rename the various files for %%doc inclusion.
%add_to_doc_files JavaScriptCore/icu/LICENSE
%add_to_doc_files WebKit/LICENSE
%add_to_doc_files WebCore/icu/LICENSE
%add_to_doc_files WebCore/LICENSE-APPLE
%add_to_doc_files WebCore/LICENSE-LGPL-2
%add_to_doc_files WebCore/LICENSE-LGPL-2.1
%add_to_doc_files JavaScriptCore/pcre/COPYING
%add_to_doc_files JavaScriptCore/COPYING.LIB
%add_to_doc_files JavaScriptCore/icu/README
%add_to_doc_files WebKit/gtk/po/README
%add_to_doc_files JavaScriptCore/AUTHORS
%add_to_doc_files JavaScriptCore/pcre/AUTHORS
%add_to_doc_files JavaScriptCore/THANKS
%add_to_doc_files WebKit/gtk/NEWS


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files -f webkit-3.0.lang
%defattr(-,root,root,-)
%doc %{_docdir}/%{name}-%{version}/
%exclude %{_libdir}/*.la
%{_libdir}/libwebkitgtk-3.0.so.*
%{_libdir}/girepository-1.0/WebKit-3.0.typelib
%{_libdir}/girepository-1.0/JSCore-3.0.typelib
%{_libexecdir}/%{name}/

%files  devel
%defattr(-,root,root,-)
%{_bindir}/jsc-3
%{_datadir}/webkit-3.0
%{_includedir}/webkit-3.0
%{_libdir}/libwebkitgtk-3.0.so
%{_libdir}/pkgconfig/webkitgtk-3.0.pc
%{_datadir}/gir-1.0/WebKit-3.0.gir
%{_datadir}/gir-1.0/JSCore-3.0.gir


%changelog
* Fri Jul  9 2010 Matthias Clasen <mclasen@redhat.com> 1.3.2-2
- Fix conflicting gettext domain with webkitgtk
- Drop the -doc subpackage

* Thu Jul  1 2010 Matthias Clasen <mclasen@redhat.com> 1.3.2-1
- Initial packaging
